@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import re
 import shutil
@@ -111,7 +113,7 @@ class Renderer:
         The elements of `prefix` must contain only "/", and not os.sep.
         """
         full_prefix = "/".join(prefix)
-        env_templates: t.List[str] = self.environment.loader.list_templates()
+        env_templates: list[str] = self.environment.loader.list_templates()
         for template in env_templates:
             if template.startswith(full_prefix):
                 # Exclude templates that match certain patterns
@@ -368,7 +370,7 @@ def get_env_release(root: str) -> t.Optional[str]:
     return get_release(version)
 
 
-def get_package_release() -> str:
+def get_current_open_edx_release_name() -> str:
     """
     Return the release name associated to this package.
     """
